==> qtwebengine-opensource-src_5.7.1+dfsg.orig.tar.xz: qtwebengine-opensource-src-5.7.1/src/3rdparty/chromium/components/version_ui/version_ui_constants.cc <==
// Copyright 2015 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "components/version_ui/version_ui_constants.h"

namespace version_ui {

// Resource paths.
const char kAboutVersionCSS[] = "about_version.css";
const char kVersionJS[] = "version.js";

// Message handlers.
const char kRequestVersionInfo[] = "requestVersionInfo";
const char kReturnFilePaths[] = "returnFilePaths";
const char kReturnFlashVersion[] = "returnFlashVersion";
const char kReturnVariationInfo[] = "returnVariationInfo";

// Strings.
const char kApplicationLabel[] = "application_label";
const char kBlinkVersion[] = "blink_version";
const char kBuildID[] = "build_id";
const char kBuildIDName[] = "build_id_name";
const char kCL[] = "cl";
const char kCommandLine[] = "command_line";
const char kCommandLineName[] = "command_line_name";
const char kCompany[] = "company";
const char kCopyright[] = "copyright";
const char kExecutablePath[] = "executable_path";
const char kExecutablePathName[] = "executable_path_name";
const char kFlashPlugin[] = "flash_plugin";
const char kFlashVersion[] = "flash_version";
const char kJSEngine[] = "js_engine";
const char kJSVersion[] = "js_version";
const char kOfficial[] = "official";
const char kOSName[] = "os_name";
const char kOSType[] = "os_type";
const char kOSVersion[] = "os_version";
const char kPlatform[] = "platform";
const char kProfilePath[] = "profile_path";
const char kProfilePathName[] = "profile_path_name";
const char kRevision[] = "revision";
const char kTitle[] = "title";
const char kUserAgent[] = "useragent";
const char kUserAgentName[] = "user_agent_name";
const char kVariationsName[] = "variations_name";
const char kVersion[] = "version";
const char kVersionBitSize[] = "version_bitsize";
const char kVersionModifier[] = "version_modifier";

}  // namespace version_ui

==> qtwebengine-opensource-src-5.8.0.tar.xz: qtwebengine-opensource-src-5.8.0/src/3rdparty/chromium/components/version_ui/version_ui_constants.cc <==
// Copyright 2015 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "components/version_ui/version_ui_constants.h"

namespace version_ui {

// Resource paths.
const char kAboutVersionCSS[] = "about_version.css";
const char kVersionJS[] = "version.js";

// Message handlers.
const char kRequestVersionInfo[] = "requestVersionInfo";
const char kReturnFilePaths[] = "returnFilePaths";
const char kReturnFlashVersion[] = "returnFlashVersion";
const char kReturnVariationInfo[] = "returnVariationInfo";

// Strings.
const char kApplicationLabel[] = "application_label";
const char kARC[] = "arc_label";
const char kBlinkVersion[] = "blink_version";
const char kCL[] = "cl";
const char kCommandLine[] = "command_line";
const char kCommandLineName[] = "command_line_name";
const char kCompany[] = "company";
const char kCopyright[] = "copyright";
const char kExecutablePath[] = "executable_path";
const char kExecutablePathName[] = "executable_path_name";
const char kFlashPlugin[] = "flash_plugin";
const char kFlashVersion[] = "flash_version";
const char kJSEngine[] = "js_engine";
const char kJSVersion[] = "js_version";
const char kOfficial[] = "official";
const char kOSName[] = "os_name";
const char kOSType[] = "os_type";
const char kOSVersion[] = "os_version";
const char kPlatform[] = "platform";
const char kProfilePath[] = "profile_path";
const char kProfilePathName[] = "profile_path_name";
const char kRevision[] = "revision";
const char kTitle[] = "title";
const char kUserAgent[] = "useragent";
const char kUserAgentName[] = "user_agent_name";
const char kVariationsName[] = "variations_name";
const char kVersion[] = "version";
const char kVersionBitSize[] = "version_bitsize";
const char kVersionModifier[] = "version_modifier";

}  // namespace version_ui
